require_relative 'team_member'

module PeopleGroup
  module HRIS
    module Wrappers
      class BambooTeamMember < TeamMember
        def initialize(data)
          @data = data
        end

        MAPPED_ITEMS = ['department', 'division']
        MAPPED_ITEMS.each do |item|
          define_method("#{item}") do
            @data[item]
          end
        end

        def team_member_id
          @data['id']
        end

        def first_name
          @data['preferredName'] || @data['firstName']
        end

        def last_name
          @data['customPreferredLastName'] || @data['lastName']
        end

        def active?
          @data['status'] == 'Active'
        end

        def start_date
          return unless @data['hireDate']

          Date.parse(@data['hireDate'])
        end

        def specialties
          @data['customJobTitleSpecialty(Multi-Select)'] || @data['customJobTitleSpeciality'] || ''
        end

        def gitlab_username
          @data['customGitLabUsername']
        end

        def work_email
          @data['workEmail']
        end

        def offboarded?
          today = Date.current
          employment_statuses = hr_client.employee.table_data(team_member_id, 'employmentStatus')
          return false if employment_statuses.size <= 1

          employment_statuses.any? do |status|
            ['Garden Leave', 'Terminated'].include?(status['employmentStatus']) && Date.parse(status['date']) >= today
          end
        end

        private

        def hr_client
          @client ||= Bamboozled.client(subdomain: ENV['BAMBOO_SUBDOMAIN'], api_key: ENV['BAMBOO_API_KEY'])
        end
      end
    end
  end
end
